@@ -1,4 +1,4 @@
-//$Id: blob-res.cc,v 1.12 2002/06/14 21:37:52 cactus Exp $ -*- c++ -*-
+//$Id: blob-res.cc,v 1.13 2003/01/25 00:33:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,9 +21,9 @@
 
 using namespace Guikachu;
 
-Resources::Blob::Blob (ResourceManager   *owner,
+Resources::Blob::Blob (ResourceManager   *manager,
 		       const std::string &id):
-    Resource (owner, id),
+    Resource (manager, id),
     gui (0),
     contents (changed, "")
 {
