@@ -1,4 +1,4 @@
-//$Id: blob-win.cc,v 1.4 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: blob-win.cc,v 1.7 2002/10/27 22:17:14 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -25,6 +25,8 @@
 #include <libgnomeui/gnome-window-icon.h>
 #endif
 
+#include "property-ops-resource.h"
+
 #include "widgets/propertytable.h"
 #include "widgets/entry.h"
 #include "widgets/text.h"
@@ -33,10 +35,12 @@ using namespace Guikachu;
 
 GUI::BlobWindow::BlobWindow (Guikachu::Resources::Blob *res_):
     res (res_),
-    window (new Gtk::Window (GTK_WINDOW_DIALOG))
+    window (new Gtk::Window)
 {
     using namespace SigC;
-
+    using ResourceOps::RenameOpFactory;
+    using ResourceOps::PropChangeOpFactory;
+    
     window->delete_event.connect (slot (this, &BlobWindow::delete_event_impl));
     window->set_policy (false, true, false);
     
@@ -48,11 +52,14 @@ GUI::BlobWindow::BlobWindow (Guikachu::Resources::Blob *res_):
     Gtk::Widget *control;
 
     /* Resource ID */
-    control = new GUI::PropertyEditors::Entry (false, res->id);
+    control = new GUI::PropertyEditors::Entry (false, res->id, new RenameOpFactory (res));
     proptable->add (_("Resource _ID:"), *manage (control));
 
     /* Blob contents */
-    control = new GUI::PropertyEditors::TextArea (res->contents);
+    control = new GUI::PropertyEditors::TextArea (
+	res->contents,
+	new PropChangeOpFactory<std::string> (
+	    _("Change contents of %s"), res, res->contents, true));
     proptable->add (_("_Blob:"), *manage (control));
     
     window->add (*manage (proptable));
