@@ -1,4 +1,4 @@
-//$Id: dialog-res.cc,v 1.23 2002/06/14 21:37:52 cactus Exp $ -*- c++ -*-
+//$Id: dialog-res.cc,v 1.24 2003/01/25 00:33:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,16 +21,16 @@
 
 using namespace Guikachu;
 
-Resources::Dialog::Dialog (ResourceManager   *owner,
+Resources::Dialog::Dialog (ResourceManager   *manager,
 			   const std::string &id):
-    Resource (owner, id),
+    Resource (manager, id),
     gui (0),
     title (changed, ""),
     text (changed, ""),
     dialog_type (changed, TYPE_INFORMATION),
     buttons (changed),
     default_button (changed, 0),
-    help_id (changed, owner, "")
+    help_id (changed, manager, "")
 {
 }
 
