@@ -1,4 +1,4 @@
-//$Id: button.h,v 1.19 2002/06/14 21:37:53 cactus Exp $ -*- c++ -*-
+//$Id: button.h,v 1.20 2002/08/01 18:06:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -51,14 +51,14 @@ namespace Guikachu
 	    GUI::FormEditor::ButtonProperties *editor;
 	    
 	public:
-	    Button (Resources::Form   *owner,
-		    const std::string &id);
-	    virtual ~Button ();
+	    Button (Resources::Form *owner, const std::string &id);
+	    ~Button ();
 	    
-	    virtual Type get_type () const { return WIDGET_BUTTON; };
+	    Type get_type () const { return WIDGET_BUTTON; };
+	    void apply_visitor (WidgetVisitor &visitor) { visitor.visit_widget (this); };
 	    
-	    virtual Gtk::Widget                       *create_editor ();
-	    virtual GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group);
+	    Gtk::Widget                       *create_editor ();
+	    GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group);
 
 	    enum FrameType
 	    {
