@@ -1,4 +1,4 @@
-//$Id: form-canvas.h,v 1.5 2002/06/22 13:01:09 cactus Exp $ -*- c++ -*-
+//$Id: form-canvas.h,v 1.6 2003/01/26 17:35:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -47,15 +47,12 @@ namespace Guikachu
 	    {		
 		Resources::Form    *res;
 
-		Gnome::CanvasGroup *group;
 		Gnome::CanvasItem  *background_item;
 		Gnome::CanvasGroup *frame_group;
 		Gnome::CanvasGroup *title_group;
 		Gnome::CanvasGroup *widget_group;
 		Gnome::CanvasItem  *bounding_box;
 
-		Gtk::Menu           popup_menu;
-
 	    public:
 		FormCanvasItem (Widgets::Form      *form_widget,
 				Gnome::CanvasGroup *parent_group);
@@ -66,6 +63,7 @@ namespace Guikachu
 
 		Gnome::CanvasGroup *get_widget_group ();
 
+		SigC::Signal2<void, guint, guint32> context_menu;
 		SigC::Signal1<void, bool> selected;
 		
 	    private:
