@@ -1,4 +1,4 @@
-//$Id: gadget.h,v 1.8 2002/06/14 21:37:53 cactus Exp $ -*- c++ -*-
+//$Id: gadget.h,v 1.9 2002/08/01 18:06:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -42,14 +42,14 @@ namespace Guikachu
 	    GUI::FormEditor::GadgetProperties *editor;
 	    
 	public:
-	    Gadget (Resources::Form   *owner,
-		    const std::string &id);
-	    virtual ~Gadget ();
+	    Gadget (Resources::Form *owner, const std::string &id);
+	    ~Gadget ();
 	    
-	    virtual Type get_type () const { return WIDGET_GADGET; };
+	    Type get_type () const { return WIDGET_GADGET; };
+	    void apply_visitor (WidgetVisitor &visitor) { visitor.visit_widget (this); };
 	    
-	    virtual Gtk::Widget                       *create_editor ();
-	    virtual GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group);
+	    Gtk::Widget                       *create_editor ();
+	    GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group);
 
 	    Property<bool> usable;
 	};
