@@ -1,4 +1,4 @@
-//$Id: glyph.cc,v 1.4 2002/01/12 14:12:03 cactus Exp $ -*- c++ -*-
+//$Id: glyph.cc,v 1.7 2002/06/29 22:13:50 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,34 +18,34 @@
 
 #include "font.h"
 
-#include <strstream>
+#include <sstream>
 
 using namespace Guikachu::GUI::FormEditor;
 
 #define GLYPH_ON  '#'
 #define GLYPH_OFF '-'
 
-Glyph::Glyph (unsigned int height, unsigned int ascent):
+Glyph::Glyph (int height, int ascent):
     width (5),
     bitmap (0)
 {
     bitmap = new bool*[height];
     
-    for (unsigned int i = 0; i < height; i++)
+    for (int i = 0; i < height; i++)
     {
 	bitmap[i] = g_new0 (bool, width);
     }
 
-    unsigned int y1 = ascent - 8;
-    unsigned int y2 = ascent - 1;
+    int y1 = ascent - 8;
+    int y2 = ascent - 1;
 
-    for (unsigned int x = 0; x < width; x++)
+    for (int x = 0; x < width; x++)
     {
 	bitmap[y1][x] = true;
 	bitmap[y2][x] = true;
     }
 
-    for (unsigned int y = y1; y < y2; y++)
+    for (int y = y1; y < y2; y++)
     {
 	bitmap[y][0] = true;
 	bitmap[y][4] = true;
@@ -53,7 +53,7 @@ Glyph::Glyph (unsigned int height, unsigned int ascent):
 }
 
 Glyph::Glyph (std::istream &stream,
-	      unsigned int &height):
+	      int          &height):
     width (0),
     offset (0),
     bitmap (0)
@@ -74,19 +74,20 @@ Glyph::Glyph (std::istream &stream,
 	    continue;
 	}
 
-	std::strstream curr_line_stream;
-	std::string    param_name;
-	int            param_val;
+	std::stringstream curr_line_stream;
+	std::string       param_name;
+	int               param_val;
 	
 	curr_line_stream << curr_line;
 	curr_line_stream >> param_name;
-	curr_line_stream >> param_val;
+	if (!(curr_line_stream >> param_val))
+	    param_val = 0;
 
 	if (param_name == "OFFSET")
 	    offset = param_val;
     }
 
-    unsigned int row = 0;
+    int row = 0;
     
     while (in_bitmap)
     {
@@ -102,7 +103,7 @@ Glyph::Glyph (std::istream &stream,
 	bitmap = (bool**) realloc (bitmap, (row + 1) * sizeof (bool*));
 	bitmap[row] = new bool[width];
 
-	for (unsigned int i = 0; i < width; i++)
+	for (int i = 0; i < width; i++)
 	    bitmap[row][i] = (curr_line[i] == GLYPH_ON) ? true : false;
 	
 	getline (stream, curr_line);
