@@ -1,4 +1,4 @@
-//$Id: graffiti.cc,v 1.12 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: graffiti.cc,v 1.16 2002/06/19 21:57:39 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -50,41 +50,12 @@ WidgetCanvasItem* Graffiti::create_canvas_item (Gnome::CanvasGroup *parent_group
     return new GraffitiCanvasItem (this, parent_group);
 }
 
-bool Graffiti::load (StorageNode &node)
+int Graffiti::get_width () const
 {
-    for (StorageNode curr_node  = node.children ();
-	 curr_node; curr_node++)
-    {
-	if (curr_node.name () == "pos")
-	{
-	    x = curr_node.get_prop<int> ("x");
-	    y = curr_node.get_prop<int> ("y");
-	}
-	else
-	    g_warning ("Error parsing `graffiti' widget: "
-		       "unexpected element `%s'",
-		       curr_node.name ().c_str ());
-    }
-
-    changed ();
-
-    return true;
+    return 8;
 }
 
-void Graffiti::save (StorageNode &node) const
+int Graffiti::get_height () const
 {
-    StorageNode my_node;
-
-    /* Position */
-    my_node = node.add_node ("pos");
-    my_node.set_prop ("x", x);
-    my_node.set_prop ("y", y);
+    return 9;
 }
-
-void Graffiti::save_rcp (std::ostream &ostr) const
-{
-    ostr << "  GRAFFITISTATEINDICATOR";
-    ostr << " AT (" << x << " " << y << ")";
-    ostr << std::endl;
-}
-
