@@ -1,4 +1,4 @@
-//$Id: label.cc,v 1.26 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: label.cc,v 1.30 2002/06/19 21:57:39 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,6 +19,8 @@
 #include "label.h"
 #include "label-canvas.h"
 
+#include "form-editor.h"
+
 using Guikachu::Widgets::Label;
 using namespace Guikachu::GUI::FormEditor;
 
@@ -50,63 +52,18 @@ WidgetCanvasItem* Label::create_canvas_item (Gnome::CanvasGroup *parent_group)
     return new LabelCanvasItem (this, parent_group);
 }
 
-bool Label::load (StorageNode &node)
+int Label::get_width  () const
 {
-    /* Non-NULL default values */
-    usable = false;
+    int width = 0, height = 0;
+    GUI::FormEditor::get_text_extents (font, text, width, height);
+
+    return width;
+}
+
+int Label::get_height () const
+{
+    int width = 0, height = 0;
+    GUI::FormEditor::get_text_extents (font, text, width, height);
     
-    for (StorageNode curr_node  = node.children ();
-	 curr_node; curr_node++)
-    {
-	if (curr_node.name () == "pos")
-	{
-	    x = curr_node.get_prop<int> ("x");
-	    y = curr_node.get_prop<int> ("y");
-	}
-	else if (curr_node.name () == "text")
-	{
-	    text = curr_node.get_content ();
-	    font = curr_node.get_prop<int> ("font");
-	}
-	else if (curr_node.name () == "usable")
-	    usable = true;
-	else
-	    g_warning ("Error parsing `label' widget: "
-		       "unexpected element `%s'",
-		       curr_node.name ().c_str ());
-    }
-
-    changed ();
-
-    return true;
-}
-
-void Label::save (StorageNode &node) const
-{
-    StorageNode my_node;
-
-    /* Position */
-    my_node = StorageNode (node).add_node ("pos");
-    my_node.set_prop ("x", x);
-    my_node.set_prop ("y", y);
-
-    /* Usable */
-    if (usable)
-	node.add_node ("usable");
-    
-    /* Text and font */
-    my_node = node.add_node ("text", text);
-    my_node.set_prop ("font", font);
-}
-
-void Label::save_rcp (std::ostream &ostr) const
-{
-    ostr << "  LABEL \"" << text << "\"" << " ID " << id;
-    ostr << " AT (" << x << " " << y << ")";
-    ostr << " FONT " << font;
-    if (usable)
-	ostr << " USABLE";
-    else
-	ostr << " NONUSABLE";
-    ostr << std::endl;
+    return height;
 }
