@@ -1,4 +1,4 @@
-//$Id: list-canvas.cc,v 1.24 2002/06/19 21:57:39 cactus Exp $ -*- c++ -*-
+//$Id: list-canvas.cc,v 1.26 2002/10/27 22:17:15 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,6 +19,7 @@
 #include "list-canvas.h"
 
 #include "form-editor.h"
+#include "resizeable-ops.h"
 
 #include <gnome--/canvas.h>
 #include <gnome--/canvas-property.h>
@@ -29,7 +30,7 @@ ListCanvasItem::ListCanvasItem (Widgets::List      *widget_,
 				Gnome::CanvasGroup *parent_group):
     CanvasItem (widget_, parent_group),
     WidgetCanvasItem (widget_, parent_group),
-    ResizeableCanvasItem (widget_, parent_group),
+    ResizeableCanvasItem (widget_, parent_group, new WidgetOps::ResizeOpFactory (widget_)),
     widget (widget_),
     group (0)
 {
