@@ -1,4 +1,4 @@
-//$Id: list.h,v 1.16 2002/06/19 21:57:39 cactus Exp $ -*- c++ -*-
+//$Id: list.h,v 1.17 2002/08/01 18:06:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -46,14 +46,14 @@ namespace Guikachu
 	    SigC::Signal0<void> manual_width_changed;
 	    
 	public:
-	    List (Resources::Form   *owner,
-		  const std::string &id);
-	    virtual ~List ();
+	    List (Resources::Form *owner, const std::string &id);
+	    ~List ();
 	    
-	    virtual Type get_type () const { return WIDGET_LIST; };
+	    Type get_type () const { return WIDGET_LIST; };
+	    void apply_visitor (WidgetVisitor &visitor) { visitor.visit_widget (this); };
 	    
-	    virtual Gtk::Widget                       *create_editor ();
-	    virtual GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group);
+	    Gtk::Widget                       *create_editor ();
+	    GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group);
 
 	    Property<int>                       font;
 	    Property<int>                       visible_items;
