@@ -1,4 +1,4 @@
-//$Id: pushbutton-prop.cc,v 1.12 2002/01/26 00:19:16 cactus Exp $ -*- c++ -*-
+//$Id: pushbutton-prop.cc,v 1.16 2002/10/27 22:17:15 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -30,14 +30,16 @@
 #include "widgets/togglebutton.h"
 #include "widgets/propertytable.h"
 
+#include "property-ops-widget.h"
+
 using namespace Guikachu::GUI::FormEditor;
 using namespace Guikachu::Widgets;
 
 PushButtonProperties::PushButtonProperties (PushButton *res)
 {
-    using namespace Gtk;
     using namespace SigC;
-
+    using WidgetOps::PropChangeOpFactory;
+    
     GUI::PropertyTable *proptable = new GUI::PropertyTable ();
     Gtk::Widget *control;
     
@@ -48,12 +50,16 @@ PushButtonProperties::PushButtonProperties (PushButton *res)
     TextualProperties::add_controls (res, *proptable);
 
     /* Usable */
-    control = new GUI::PropertyEditors::ToggleButton (res->usable);
+    control = new GUI::PropertyEditors::ToggleButton (
+	res->usable,
+	new PropChangeOpFactory<bool> (_("Toggle usable state of %s"), res, res->usable, false));
     proptable->add (_("_Usable:"), *manage (control),
 		    _("Non-usable widgets are not rendered by default"));
 
     /* Group ID */
-    control = new GUI::PropertyEditors::NumEntry(0, 65535, res->group);
+    control = new GUI::PropertyEditors::NumEntry(
+	0, 65535, res->group,
+	new PropChangeOpFactory<int> (_("Change group ID of %s"), res, res->group, true));
     proptable->add (_("_Group ID:"), *manage (control),
 		    _("Only one push button can be selected "
 		      "per group (select 0 for non-exclusive "
