@@ -1,4 +1,4 @@
-//$Id: resizeable.cc,v 1.8 2002/03/17 17:53:49 cactus Exp $ -*- c++ -*-
+//$Id: resizeable.cc,v 1.9 2002/06/19 21:57:39 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -29,12 +29,12 @@ Resizeable::Resizeable (Property<int> &real_width,
 {
 }
 
-int Resizeable::get_display_width  () const
+int Resizeable::get_width  () const
 {
     return width;
 }
 
-int Resizeable::get_display_height () const
+int Resizeable::get_height () const
 {
     return height;
 }
