@@ -1,4 +1,4 @@
-//$Id: table-canvas.h,v 1.4 2002/01/01 21:23:41 cactus Exp $ -*- c++ -*-
+//$Id: table-canvas.h,v 1.5 2002/07/09 20:02:57 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,6 +21,7 @@
 
 #include "table.h"
 #include "widget-canvas.h"
+#include "resizeable-canvas.h"
 
 namespace Guikachu
 {
@@ -28,7 +29,8 @@ namespace Guikachu
     {
 	namespace FormEditor
 	{
-	    class TableCanvasItem: public WidgetCanvasItem
+	    class TableCanvasItem: public WidgetCanvasItem,
+				   public ResizeableCanvasItem
 	    {
 		Widgets::Table     *widget;
 		Gnome::CanvasGroup *group;
