@@ -1,4 +1,4 @@
-//$Id: table.cc,v 1.18 2002/07/09 20:02:57 cactus Exp $ -*- c++ -*-
+//$Id: table.cc,v 1.19 2003/01/25 00:33:04 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -61,11 +61,12 @@ WidgetCanvasItem* Table::create_canvas_item (Gnome::CanvasGroup *parent_group)
 int Table::get_auto_width  () const
 {
     const std::vector<int> &columns = column_width;
+    int columns_size = num_columns;
 
-    // We add num_columns because each separator is one pixel
+    // We add columns_size because each separator is one pixel
     return std::accumulate (columns.begin (),
-			    columns.begin () + num_columns,
-			    num_columns);
+			    columns.begin () + columns_size,
+			    columns_size);
 }
 
 int Table::get_auto_height () const
