@@ -1,4 +1,4 @@
-//$Id: widget-canvas.cc,v 1.8 2002/06/22 13:01:09 cactus Exp $ -*- c++ -*-
+//$Id: widget-canvas.cc,v 1.10 2003/01/26 17:35:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,8 +23,6 @@
 
 #include <gtk--/main.h>
 #include <gnome--/canvas-rect.h>
-#include <gnome--/app-helper.h>
-#include <libgnomeui/gnome-stock.h>
 
 #include <list>
 #include <algorithm>
@@ -45,18 +43,7 @@ WidgetCanvasItem::WidgetCanvasItem (Widget             *widget_,
 {
     // Chain signal callbacks
     canvas_item_changed.connect (SigC::slot (this, &WidgetCanvasItem::canvas_item_changed_cb));
-    
-    // Popup menu
-    std::list <Gnome::UI::Info> popup_menu_list;
-    popup_menu_list.push_back (
-	Gnome::UI::Item (Gnome::UI::Icon (GNOME_STOCK_MENU_PROP),
-			 _("_Edit"), menu_edit.slot ()));
-    popup_menu_list.push_back (
-	Gnome::UI::Item (Gnome::UI::Icon (GNOME_STOCK_MENU_TRASH),
-			 _("_Remove"), menu_remove.slot ()));
-    
-    Gnome::UI::fill (popup_menu, popup_menu_list, *(popup_menu.get_accel_group ()));
-    
+
     widget->changed.connect  (SigC::slot (this, &WidgetCanvasItem::update));
     widget->selected.connect (SigC::slot (this, &WidgetCanvasItem::widget_selected_cb));
 }
@@ -79,7 +66,9 @@ void WidgetCanvasItem::canvas_event_cb (GdkEvent *e)
     // Context menu
     if ((e->type == GDK_BUTTON_PRESS) &&
 	(e->button.button == 3))
-	popup_menu.popup (e->button.button, e->button.time);
+    {
+	context_menu.emit (e->button.button, e->button.time);
+    }
 }
 
 Gnome::CanvasItem * WidgetCanvasItem::create_selection_box ()
@@ -119,5 +108,5 @@ void WidgetCanvasItem::widget_selected_cb (bool selected_)
     selection_box = create_selection_box ();
     selection_box->lower_to_bottom ();
     
-    parent_group->raise_to_top ();
+    item_group->raise_to_top ();
 }
