@@ -1,4 +1,4 @@
-//$Id: form-res.cc,v 1.35 2002/06/02 13:53:36 cactus Exp $ -*- c++ -*-
+//$Id: form-res.cc,v 1.36 2003/01/25 00:33:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -40,13 +40,13 @@
 using namespace Guikachu::Resources;
 using namespace Guikachu;
 
-Form::Form (ResourceManager   *owner,
+Form::Form (ResourceManager   *manager,
 	    const std::string &id):
-    Resource (owner, id),
+    Resource (manager, id),
     gui (0),
     title (changed, id),
-    help_id (changed, owner),
-    menu_id (changed, owner),
+    help_id (changed, manager),
+    menu_id (changed, manager),
     modal (changed, false),
     frame (changed, true),
     savebehind (changed, true),
@@ -63,7 +63,7 @@ Form::~Form ()
     for (std::set<Widget*>::iterator i = widgets.begin ();
 	 i != widgets.end (); i++)
     {
-	owner->unregister_id ((*i)->id);
+	manager->unregister_id ((*i)->id);
 	delete (*i);
 	widgets.erase (i);
     }
@@ -80,15 +80,24 @@ void Form::show_ui ()
 }
 
 Widget* Form::create_widget (Widgets::Type type,
-			     std::string   id)
+			     std::string   id,
+			     bool          try_alternate_names)
 {
-    id = owner->validate_id (id);
+    id = manager->validate_id (id);
     
     if (id == "")
-	id = owner->create_id (Widgets::prefix_from_type (type));
+	id = manager->create_id (Widgets::prefix_from_type (type));
     
-    if (!owner->register_id (id))
-	return 0;
+    if (!manager->register_id (id))
+    {
+	if (try_alternate_names)
+	{
+	    id = manager->create_id (id + "_");
+	    manager->register_id (id);
+	} else {
+	    return 0;
+	}
+    }
 	
     Widget *widget = 0;
 
@@ -152,7 +161,7 @@ void Form::remove_widget (Widget *widget)
     widget_removed.emit (widget);
 
     widgets.erase (widget);
-    owner->unregister_id (widget->id);
+    manager->unregister_id (widget->id);
     
     delete widget;
 
@@ -175,11 +184,11 @@ Widget* Form::get_widget (const std::string& id) const
 
 int Form::get_screen_width () const
 {
-    return owner->get_target ()->screen_width;
+    return manager->get_target ()->screen_width;
 }
 
 int Form::get_screen_height () const
 {
-    return owner->get_target ()->screen_height;
+    return manager->get_target ()->screen_height;
 }
 
