@@ -1,4 +1,4 @@
-//$Id: form-win-selection.cc,v 1.3 2002/05/01 21:02:29 cactus Exp $ -*- c++ -*-
+//$Id: form-win-selection.cc,v 1.6 2003/01/26 17:35:51 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,7 +22,7 @@ using namespace Guikachu::GUI;
 
 void FormWindow::selection_add (Widget *widget)
 {
-    selected_widgets.insert (widget);
+    selection.insert (widget);
     widget->selected (true);
 
     if (last_widget != widget)
@@ -35,7 +35,7 @@ void FormWindow::selection_add (Widget *widget)
 
 void FormWindow::selection_remove (Widget *widget)
 {
-    selected_widgets.erase (widget);
+    selection.erase (widget);
     widget->selected (false);
 
     if (last_widget == widget)
@@ -44,7 +44,7 @@ void FormWindow::selection_remove (Widget *widget)
 
 void FormWindow::selection_toggle (Widget *widget)
 {
-    if (selected_widgets.find (widget) == selected_widgets.end ())
+    if (selection.find (widget) == selection.end ())
 	selection_add (widget);
     else
 	selection_remove (widget);
@@ -52,17 +52,16 @@ void FormWindow::selection_toggle (Widget *widget)
 
 void FormWindow::selection_clear ()
 {
-    for (std::set<Widget*>::iterator i = selected_widgets.begin ();
-	 i != selected_widgets.end (); i++)
+    for (selection_t::iterator i = selection.begin (); i != selection.end (); i++)
 	(*i)->selected (false);
 
-    if (selected_widgets.find (last_widget) != selected_widgets.end ())
+    if (selection.find (last_widget) != selection.end ())
 	last_widget->selected_last (false);
 
     // FIXME: de-select form when clicking on background
 //    form_widget->selected_last (false);
     
-    selected_widgets.clear ();
+    selection.clear ();
 }
 
 void FormWindow::select_form ()
@@ -89,6 +88,19 @@ void FormWindow::select_form ()
     show_form_property_editor ();
 }
 
+void FormWindow::select_all ()
+{
+    top_treeitem->deselect ();
+    
+    form_widget->selected (false);
+    form_widget->selected_last (false);
+
+    const std::set<Widget*> &widgets = res->get_widgets ();
+    for (std::set<Widget*>::const_iterator i = widgets.begin ();
+	 i != widgets.end (); ++i)
+	selection_add (*i);
+}
+
 void FormWindow::widget_selected_last_cb (bool selected, Widget *widget)
 {
     if (selected)
@@ -118,7 +130,7 @@ void FormWindow::select_widget (Widget *widget)
     
     if (!add_to_selection)
     {
-	if (selected_widgets.find (widget) == selected_widgets.end ())
+	if (selection.find (widget) == selection.end ())
 	    selection_clear ();
 	selection_add (widget);
     } else {
@@ -149,8 +161,7 @@ void FormWindow::selection_box_cb (int x1, int y1,
 	selection_clear ();
 
     const std::set<Widget*>& widgets = res->get_widgets ();
-    for (std::set<Widget*>::const_iterator i = widgets.begin ();
-	 i != widgets.end (); i++)
+    for (std::set<Widget*>::const_iterator i = widgets.begin (); i != widgets.end (); i++)
     {
 	FormEditor::WidgetCanvasItem *canvas_item =
 	    (*i)->get_canvas_item (form_canvas_item->get_widget_group ());
