@@ -1,4 +1,4 @@
-//$Id: form-win.cc,v 1.60 2002/10/27 22:17:14 cactus Exp $ -*- c++ -*-
+//$Id: form-win.cc,v 1.63 2003/01/28 19:09:56 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -36,6 +36,9 @@
 #include <gnome--/canvas-group.h>
 #include <gnome--/canvas-polygon.h>
 
+#include <gnome--/app-helper.h>
+#include <libgnomeui/gnome-stock.h>
+
 #include <sigc++/retbind.h>
 
 #include "form-win-helpers.h"
@@ -44,6 +47,11 @@
 #include "target.h"
 #include "form-editor/widget-ops.h"
 
+#include "pixmaps/menu-align-left.xpm"
+#include "pixmaps/menu-align-right.xpm"
+#include "pixmaps/menu-align-top.xpm"
+#include "pixmaps/menu-align-bottom.xpm"
+
 using namespace Guikachu::GUI;
 using namespace Guikachu::Resources;
 
@@ -58,10 +66,12 @@ FormWindow::FormWindow (Form *res_):
 
     window     (Gtk::wrap (GTK_WINDOW      (glade_xml_get_widget (gui, "res_form")))),
     canvas     (Gtk::wrap (GNOME_CANVAS    (glade_xml_get_widget (gui, "form_canvas")))),
-    zoom_entry (Gtk::wrap (GTK_SPIN_BUTTON (glade_xml_get_widget (gui, "form_zoom_entry")))),    
+    zoom_entry (Gtk::wrap (GTK_SPIN_BUTTON (glade_xml_get_widget (gui, "form_zoom_entry")))),
 
     edited_widget (0),
     last_widget (0),
+    form_popup_menu (0),
+    widget_popup_menu (0),
     canvas_overlay (0),
     palette_selection (Widgets::WIDGET_NONE)
 {
@@ -99,6 +109,7 @@ FormWindow::FormWindow (Form *res_):
     form_canvas_item->released.connect (slot (this, &FormWindow::form_released_cb));
     form_canvas_item->drag_motion.connect (slot (this, &FormWindow::form_drag_motion_cb));
     form_canvas_item->drag_end.connect (slot (this, &FormWindow::form_drag_end_cb));
+    form_canvas_item->context_menu.connect (slot (this, &FormWindow::form_menu_cb));
     
     // Set up initial widgets
     const std::set<Widget*>& widgets = res->get_widgets ();
@@ -137,6 +148,9 @@ FormWindow::~FormWindow ()
     gtk_widget_destroy (GTK_WIDGET (window->gtkobj ()));
     gtk_object_unref (GTK_OBJECT (gui));
 
+    delete form_popup_menu;
+    delete widget_popup_menu;
+    
     delete form_widget;
     delete property_window;
     delete selection_canvas;
@@ -260,7 +274,7 @@ void FormWindow::widget_created_cb (Widget *widget)
     FormWindow_Helpers::WidgetTreeItem *tree_item = new FormWindow_Helpers::WidgetTreeItem (widget);
     tree_item->show ();
     tree_item->activate.connect (bind (slot (this, &FormWindow::select_widget), widget));
-    tree_item->menu_remove.connect (bind (slot (this, &FormWindow::widget_menu_remove_cb), widget));
+    tree_item->menu_remove.connect (bind (slot (this, &FormWindow::widget_remove_cb), widget));
     tree_item->menu_edit.connect (bind (slot (this, &FormWindow::select_widget), widget));
     
     tree->add (*tree_item);
@@ -270,8 +284,7 @@ void FormWindow::widget_created_cb (Widget *widget)
 
     canvas_item->clicked.connect (bind (slot (this, &FormWindow::widget_clicked_cb), widget));
     canvas_item->released.connect (bind (slot (this, &FormWindow::widget_released_cb), widget));
-    canvas_item->menu_remove.connect (bind (slot (this, &FormWindow::widget_menu_remove_cb), widget));
-    canvas_item->menu_edit.connect (bind (slot (this, &FormWindow::select_widget), widget));
+    canvas_item->context_menu.connect (bind (slot (this, &FormWindow::widget_menu_cb), widget));
     
     canvas_item->drag_motion.connect (slot (this, &FormWindow::widget_drag_motion_cb));
     canvas_item->drag_end.connect (slot (this, &FormWindow::widget_drag_end_cb));
@@ -395,6 +408,42 @@ void FormWindow::form_released_cb ()
     selection_canvas->set_active (true);
 }
 
+void FormWindow::form_menu_cb (guint   button,
+			       guint32 time)
+{
+    // Create popup menu
+    if (form_popup_menu)
+	delete form_popup_menu;
+    
+    form_popup_menu = new Gtk::Menu;
+    std::vector <Gnome::UI::Info> popup_menu_list;
+    popup_menu_list.push_back (
+	Gnome::UI::Item (Gnome::UI::Icon (GNOME_STOCK_MENU_PROP), _("_Edit form"),
+			 SigC::slot (this, &FormWindow::select_form)));
+    popup_menu_list.push_back (
+	Gnome::UI::Item (_("_Select all"),
+			 SigC::slot (this, &FormWindow::select_all)));
+    popup_menu_list.push_back (Gnome::UI::Separator ());
+    popup_menu_list.push_back (Gnome::MenuItems::Cut (
+	SigC::bind (SigC::slot (this, &FormWindow::widget_cut_cb), (Widget*)0)));
+    popup_menu_list.push_back (Gnome::MenuItems::Copy (
+	SigC::bind (SigC::slot (this, &FormWindow::widget_copy_cb), (Widget*)0)));
+    popup_menu_list.push_back (Gnome::MenuItems::Paste (
+	SigC::slot (this, &FormWindow::widget_paste_cb)));
+
+    Gnome::UI::Array<Gnome::UI::Info> popup_menu_widgets =
+	Gnome::UI::fill_and_return (*form_popup_menu, popup_menu_list,
+				    *(form_popup_menu->get_accel_group ()));
+    
+    if (!selection.size ())
+    {
+	popup_menu_widgets[3].get_widget ()->set_sensitive (false); // Cut
+	popup_menu_widgets[4].get_widget ()->set_sensitive (false); // Copy
+    }
+    
+    form_popup_menu->popup (button, time);
+}
+
 void FormWindow::widget_clicked_cb (Widget *widget)
 {
     select_widget (widget);
@@ -409,11 +458,61 @@ void FormWindow::widget_released_cb (Widget *widget)
     selection_canvas->set_active (true);
 }
 
-void FormWindow::widget_menu_remove_cb (Widget *widget)
+void FormWindow::widget_menu_cb (guint    button,
+				 guint32  time,
+				 Widget  *widget)
 {
-    g_return_if_fail (widget);
+    if (selection.find (widget) == selection.end ())
+	select_widget (widget);
     
-    if (selected_widgets.find (widget) != selected_widgets.end ())
+    // Create popup menu
+    if (widget_popup_menu)
+	delete widget_popup_menu;
+    
+    widget_popup_menu = new Gtk::Menu;
+    std::list <Gnome::UI::Info> popup_menu_list;
+    popup_menu_list.push_back (
+	Gnome::UI::Item (Gnome::UI::Icon (GNOME_STOCK_MENU_PROP), _("_Edit"),
+			 SigC::bind (SigC::slot (this, &FormWindow::select_widget), widget)));
+    popup_menu_list.push_back (Gnome::UI::Separator ());
+    popup_menu_list.push_back (Gnome::MenuItems::Cut (
+	SigC::bind (SigC::slot (this, &FormWindow::widget_cut_cb), widget)));
+    popup_menu_list.push_back (Gnome::MenuItems::Copy (
+	SigC::bind (SigC::slot (this, &FormWindow::widget_copy_cb), widget)));
+    popup_menu_list.push_back (Gnome::MenuItems::Paste (
+	SigC::slot (this, &FormWindow::widget_paste_cb)));
+    popup_menu_list.push_back (Gnome::UI::Separator ());
+    popup_menu_list.push_back (
+	Gnome::UI::Item (Gnome::UI::Icon (GNOME_STOCK_MENU_TRASH), _("_Remove"),
+			 SigC::bind (SigC::slot (this, &FormWindow::widget_remove_cb), widget)));
+    
+    if (selection.size () > 1 && selection.find (widget) != selection.end ())
+    {
+	popup_menu_list.push_back (Gnome::UI::Separator ());
+	
+	popup_menu_list.push_back (Gnome::UI::Item (
+	    Gnome::UI::Icon (Gnome::UI::Icon::DATA, menu_align_left_xpm),
+	    _("Align to _left"), SigC::slot (this, &FormWindow::align_left)));
+	popup_menu_list.push_back (Gnome::UI::Item (
+	    Gnome::UI::Icon (Gnome::UI::Icon::DATA, menu_align_right_xpm),
+	    _("Align to ri_ght"), SigC::slot (this, &FormWindow::align_right)));
+	popup_menu_list.push_back (Gnome::UI::Item (
+	    Gnome::UI::Icon (Gnome::UI::Icon::DATA, menu_align_top_xpm),
+	    _("Align to _top"), SigC::slot (this, &FormWindow::align_top)));
+	popup_menu_list.push_back (Gnome::UI::Item (
+	    Gnome::UI::Icon (Gnome::UI::Icon::DATA, menu_align_bottom_xpm),
+	    _("Align to _bottom"), SigC::slot (this, &FormWindow::align_bottom)));
+    }
+    
+    Gnome::UI::fill (*widget_popup_menu, popup_menu_list,
+		     *(widget_popup_menu->get_accel_group ()));
+
+    widget_popup_menu->popup (button, time);
+}
+
+void FormWindow::widget_remove_cb (Widget *widget)
+{
+    if (!widget || selection.find (widget) != selection.end ())
     {
 	remove_selection ();
     } else {
@@ -439,8 +538,7 @@ void FormWindow::form_drag_end_cb (int dx, int dy)
 
 void FormWindow::widget_drag_motion_cb (int dx, int dy)
 {
-    for (std::set<Widget*>::iterator i = selected_widgets.begin ();
-	 i != selected_widgets.end (); i++)
+    for (selection_t::iterator i = selection.begin (); i != selection.end (); i++)
     {
 	FormEditor::CanvasItem *canvas_item = (*i)->get_canvas_item (form_canvas_item->get_widget_group ());
 	canvas_item->move (dx, dy);
@@ -449,11 +547,10 @@ void FormWindow::widget_drag_motion_cb (int dx, int dy)
 
 void FormWindow::widget_drag_end_cb (int dx, int dy)
 {
-    UndoOp *op = new WidgetOps::MultiMoveOp (selected_widgets, dx, dy);
+    UndoOp *op = new WidgetOps::MultiMoveOp (selection, dx, dy);
     res->get_manager ()->get_undo_manager ().push (op);
 	
-    for (std::set<Widget*>::iterator i = selected_widgets.begin ();
-	 i != selected_widgets.end (); i++)
+    for (selection_t::iterator i = selection.begin (); i != selection.end (); i++)
     {
 	(*i)->x += dx;
 	(*i)->y += dy;
@@ -469,13 +566,13 @@ void FormWindow::key_press_cb (GdkEventKey *e)
 
 void FormWindow::remove_selection ()
 {
-    if (!selected_widgets.size ())
+    if (!selection.size ())
 	return;
     
-    res->get_manager ()->get_undo_manager ().push (new WidgetOps::MultiRemoveOp (selected_widgets));
+    res->get_manager ()->get_undo_manager ().push (
+	new WidgetOps::MultiRemoveOp (selection));
     
-    for (std::set<Widget*>::iterator i = selected_widgets.begin ();
-	 i != selected_widgets.end ();)
+    for (selection_t::iterator i = selection.begin (); i != selection.end ();)
     {
 	Widget *curr_widget = *(i++);
 	
