@@ -1,4 +1,4 @@
-//$Id: rcp-save-form.cc,v 1.4 2002/07/09 20:02:59 cactus Exp $ -*- c++ -*-
+//$Id: rcp-save-form.cc,v 1.6 2003/01/29 20:29:59 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -282,7 +282,7 @@ static void save_widget_list (Widgets::List *widget, std::ostream &ostr)
     const std::vector<std::string> &items = widget->items;
     for (std::vector<std::string>::const_iterator i = items.begin ();
 	 i != items.end (); i++)
-	ostr << " \"" << *i << "\"";
+	ostr << " \"" << escape_backslashes (*i) << "\"";
     
     ostr << " ID " << widget->id;
     ostr << " AT (" << widget->x << " " << widget->y << " " << width_str << " " << " AUTO)";
@@ -366,7 +366,7 @@ static void save_widget_text_field (Widgets::TextField *widget, std::ostream &os
     save_flag (widget->usable, ostr, " USABLE", " NONUSABLE");
     save_flag (widget->editable, ostr, " EDITABLE", " NONEDITABLE");
     save_flag (widget->multi_line, ostr, " MULTIPLELINES", " SINGLELINE");
-    save_flag (widget->justify_right, ostr, " RIGHTALING", " LEFTALIGN");
+    save_flag (widget->justify_right, ostr, " RIGHTALIGN", " LEFTALIGN");
     save_flag (widget->underline, ostr, " UNDERLINED");
     save_flag (widget->dynamic_size, ostr, " DYNAMICSIZE");
     save_flag (widget->auto_shift, ostr, " AUTOSHIFT");
