@@ -1,4 +1,4 @@
-//$Id: menu-res.cc,v 1.21 2002/08/13 23:55:50 cactus Exp $ -*- c++ -*-
+//$Id: menu-res.cc,v 1.24 2003/01/29 20:29:58 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,9 +22,14 @@
 using namespace Guikachu;
 using namespace Guikachu::Resources;
 
-Menu::Menu (ResourceManager   *owner,
+Menu::Submenu::Submenu (const std::string &label_) :
+    label (make_7bit_string (label_))
+{
+}
+
+Menu::Menu (ResourceManager   *manager,
 	    const std::string &id):
-    Resource (owner, id),
+    Resource (manager, id),
     gui (0)
 {
 }
@@ -42,51 +47,46 @@ void Menu::show_ui ()
     gui->show ();
 }
 
-bool Menu::register_menu (const std::vector<Resources::Menu::Submenu>& menu)
+void Menu::register_menu (const MenuTree &new_submenus)
 {
-    bool success = true;
+    submenus = new_submenus;
     
-    for (std::vector<Resources::Menu::Submenu>::const_iterator i = menu.begin ();
-	 i != menu.end (); i++)
+    for (MenuTree::iterator i = submenus.begin (); i != submenus.end (); ++i)
     {
-	for (std::vector<Resources::Menu::MenuItem>::const_iterator j = i->items.begin ();
-	     j != i->items.end (); j++)
+	for (std::vector<MenuItem>::iterator j = i->items.begin (); j != i->items.end (); ++j)
 	{
 	    if (!j->separator)
-		if (!owner->register_id (j->id))
-		    success = false;
+	    {
+		j->id = make_7bit_string (j->id);
+		j->label = make_7bit_string (j->label);
+		
+		if (!manager->register_id (j->id))
+		{
+		    j->id = manager->create_id (j->id + "_");
+		    manager->register_id (j->id);
+		}
+	    }
 	}
     }
-
-    return success;
 }
 
-void Menu::deregister_menu (const std::vector<Resources::Menu::Submenu>& menu)
+void Menu::deregister_menu ()
 {
-    for (std::vector<Resources::Menu::Submenu>::const_iterator i = menu.begin ();
-	 i != menu.end (); i++)
+    for (MenuTree::const_iterator i = submenus.begin (); i != submenus.end (); ++i)
     {
-	for (std::vector<Resources::Menu::MenuItem>::const_iterator j = i->items.begin ();
-	     j != i->items.end (); j++)
+	for (std::vector<MenuItem>::const_iterator j = i->items.begin ();
+	     j != i->items.end (); ++j)
 	{
 	    if (!j->separator)
-		owner->unregister_id (j->id);
+		manager->unregister_id (j->id);
 	}
     }
 }
 
 void Menu::set_submenus (const std::vector<Menu::Submenu>& new_menu)
 {
-    std::vector<Submenu> old_submenus = submenus;
+    deregister_menu ();
+    register_menu (new_menu);
     
-    deregister_menu (submenus);    
-    if (!register_menu (new_menu))
-    {
-	deregister_menu (new_menu);
-	register_menu (submenus);
-    } else {
-	submenus = new_menu;
-    }
-
     changed ();
 }
