@@ -1,4 +1,4 @@
-//$Id: menu-win.cc,v 1.26 2002/06/02 13:53:36 cactus Exp $ -*- c++ -*-
+//$Id: menu-win.cc,v 1.31 2002/11/02 00:58:41 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -25,10 +25,16 @@
 #include <libgnomeui/gnome-window-icon.h>
 #endif
 
+#include "property-ops-resource.h"
+#include "menu-res-ops.h"
+
 #include <sigc++/retbind.h>
+#include <gtk--/main.h>
 #include "argumentsink.h"
+#include "property-ops.h"
 
 using namespace Guikachu;
+using namespace Guikachu::ResourceOps::MenuOps;
 
 GUI::MenuWindow::MenuWindow (Guikachu::Resources::Menu *res_):
     res (res_),
@@ -276,9 +282,13 @@ void GUI::MenuWindow::id_entry_cb ()
 	return;
 
     update_block = true;
-    res->id = id_entry->get_text ();
-    update_block = false;
 
+    static ResourceOps::RenameOpFactory op_factory (res);
+
+    const std::string new_id = id_entry->get_text ();
+    op_factory.push_change (new_id);
+
+    update_block = false;
     id_entry->set_text (res->id);
 }
 
@@ -292,14 +302,22 @@ void GUI::MenuWindow::item_id_entry_cb ()
 
     unsigned int row = clist->selection ().begin ()->get_row_num ();
     unsigned int index = clist_rows[row].index;
+    unsigned int parent_index = clist_rows[row].parent_index;
+    const std::string new_id = item_id->get_text ();
 
     if (clist_rows[row].is_submenu)
 	return;
 
-    std::vector<Resources::Menu::MenuItem>& items = submenus[clist_rows[row].parent_index].items;
-    items[index].id = item_id->get_text ();
+    std::vector<Resources::Menu::MenuItem>& items = submenus[parent_index].items;
 
+    if (items[index].id == new_id)
+	return;
+    
+    items[index].id = new_id;
+
+    UndoOp *op = new MenuItemRenameOp (res, parent_index, index, new_id);
     res->set_submenus (submenus);
+    res->get_manager ()->get_undo_manager ().push (op);    
 }
 
 void GUI::MenuWindow::item_label_entry_cb ()
@@ -315,20 +333,37 @@ void GUI::MenuWindow::item_label_entry_cb ()
     unsigned int row = clist->selection ().begin ()->get_row_num ();
     unsigned int index = clist_rows[row].index;
 
+    const std::string new_label = item_label->get_text ();
+    
     if (clist_rows[row].is_submenu)
     {
-	submenus[index].label = item_label->get_text ();
+	if (submenus[index].label == new_label)
+	    return;
+	
+	submenus[index].label = new_label;
 
+	UndoOp *op = new SubmenuChangeOp (res, index, new_label);
 	res->set_submenus (submenus);
+	res->get_manager ()->get_undo_manager ().push (op);
 
     } else {
+	unsigned int parent_index = clist_rows[row].parent_index;
 
-	std::vector<Resources::Menu::MenuItem>& items = submenus[clist_rows[row].parent_index].items;
-	items[index].label = item_label->get_text ();
+	std::vector<Resources::Menu::MenuItem>& items = submenus[parent_index].items;
+	if (items[index].label == new_label)
+	    return;
 	
+	items[index].label = new_label;
+	
+	UndoOp *op = new MenuItemLabelOp (res, parent_index, index, new_label);
 	res->set_submenus (submenus);
+	res->get_manager ()->get_undo_manager ().push (op);
     }
 
+    
+    while (Gtk::Main::events_pending ())
+	Gtk::Main::iteration ();
+    
     item_label->set_position (saved_pos);
     item_label->grab_focus ();
 }
@@ -342,20 +377,28 @@ void GUI::MenuWindow::item_shortcut_entry_cb ()
 	return;
 
     unsigned int row = clist->selection ().begin ()->get_row_num ();
+
+    g_return_if_fail (!clist_rows[row].is_submenu);
+    
     unsigned int index = clist_rows[row].index;
+    unsigned int parent_index = clist_rows[row].parent_index;
 
-    if (clist_rows[row].is_submenu)
-	return;
-
-    std::vector<Resources::Menu::MenuItem>& items = submenus[clist_rows[row].parent_index].items;
+    std::vector<Resources::Menu::MenuItem>& items = submenus[parent_index].items;
     std::string shortcut_str = item_shortcut->get_text ();
-
-    if (shortcut_str == "")
-	items[index].shortcut = 0;
-    else
-	items[index].shortcut = shortcut_str[0];
-
+    char shortcut = shortcut_str == "" ? 0 : shortcut_str[0];
+    
+    
+    if (shortcut == items[index].shortcut)
+	return;
+    
+    items[index].shortcut = shortcut;
+    
+    UndoOp *op = new MenuItemShortcutOp (res, parent_index, index, shortcut);
     res->set_submenus (submenus);
+    res->get_manager ()->get_undo_manager ().push (op);
+    
+    while (Gtk::Main::events_pending ())
+	Gtk::Main::iteration ();
     
     item_shortcut->grab_focus ();
 }
@@ -369,27 +412,9 @@ void GUI::MenuWindow::btn_up_cb ()
     g_return_if_fail (index != 0);
     
     if (clist_rows[row].is_submenu)
-    {
-	std::vector<Resources::Menu::Submenu>::iterator curr = submenus.begin() + index;
-	std::vector<Resources::Menu::Submenu>::iterator prev = curr - 1;
-	int offset = prev->items.size() + 1;
-
-	iter_swap (curr, prev);
-	res->set_submenus (submenus);
-
-	clist->select_row (row - offset);
-	
-    } else {
-	
-	std::vector<Resources::Menu::MenuItem>& items = submenus[clist_rows[row].parent_index].items;
-	std::vector<Resources::Menu::MenuItem>::iterator curr = items.begin() + index;
-	std::vector<Resources::Menu::MenuItem>::iterator prev = curr - 1;
-
-	iter_swap (curr, prev);
-	res->set_submenus (submenus);
-
-	clist->select_row (row - 1);
-    }
+	submenu_up (index);
+    else
+	menuitem_up (clist_rows[row].parent_index, index);
 }
 
 void GUI::MenuWindow::btn_down_cb ()
@@ -401,30 +426,9 @@ void GUI::MenuWindow::btn_down_cb ()
 
     
     if (clist_rows[row].is_submenu)
-    {
-	g_return_if_fail (index < (submenus.size() - 1));
-    
-	std::vector<Resources::Menu::Submenu>::iterator curr = submenus.begin() + index;
-	std::vector<Resources::Menu::Submenu>::iterator next = curr + 1;
-	int offset = next->items.size() + 1;
-
-	iter_swap (curr, next);
-	res->set_submenus (submenus);
-    
-	clist->select_row (row + offset);
-
-    } else {
-	std::vector<Resources::Menu::MenuItem>& items = submenus[clist_rows[row].parent_index].items;
-	std::vector<Resources::Menu::MenuItem>::iterator curr = items.begin() + index;
-	std::vector<Resources::Menu::MenuItem>::iterator next = curr + 1;
-
-	g_return_if_fail (index < (items.size () - 1));
-	
-	iter_swap (curr, next);
-	res->set_submenus (submenus);
-
-	clist->select_row (row + 1);
-    }
+	submenu_down (index);
+    else
+	menuitem_down (clist_rows[row].parent_index, index);
 }
 
 void GUI::MenuWindow::btn_remove_cb ()
@@ -435,17 +439,9 @@ void GUI::MenuWindow::btn_remove_cb ()
     unsigned int index = clist_rows[row].index;
 
     if (clist_rows[row].is_submenu)
-    {
-	submenus.erase (submenus.begin () + index);
-	res->set_submenus (submenus);
-	
-    } else {
-
-	std::vector<Resources::Menu::MenuItem>& items = submenus[clist_rows[row].parent_index].items;
-	items.erase (items.begin () + index);
-
-	res->set_submenus (submenus);	
-    }
+	submenu_remove (index);
+    else
+	menuitem_remove (clist_rows[row].parent_index, index);
 }
 
 void GUI::MenuWindow::btn_submenu_cb ()
@@ -457,6 +453,9 @@ void GUI::MenuWindow::btn_submenu_cb ()
 
 	res->set_submenus (submenus);
 
+	
+	while (Gtk::Main::events_pending ())
+	    Gtk::Main::iteration ();	
 	item_label->grab_focus ();
 
 	return;
@@ -484,9 +483,15 @@ void GUI::MenuWindow::btn_submenu_cb ()
     submenus.insert (new_index, submenu);
     
     clist->select_row (new_row);
+
     res->set_submenus (submenus);
+    UndoOp *op = new SubmenuCreateOp (res, index);
+    res->get_manager ()->get_undo_manager ().push (op);
+    
     clist->select_row (new_row);
 
+    while (Gtk::Main::events_pending ())
+	Gtk::Main::iteration ();
     item_label->grab_focus ();
 }
 
@@ -502,7 +507,7 @@ void GUI::MenuWindow::btn_item_cb (bool separator)
     
     Resources::Menu::MenuItem menuitem;
     menuitem.separator = separator;
-    
+
     if (!separator)
     {
 	menuitem.id = res->get_manager ()->create_id ("MENUITEM_");
@@ -515,6 +520,9 @@ void GUI::MenuWindow::btn_item_cb (bool separator)
 	pos = submenus[index].items.end ();	
 	submenus[index].items.insert (pos, menuitem);
 	new_row = row + submenus[index].items.size ();
+
+	parent_index = index;
+	index = submenus[parent_index].items.size () - 1;
 	
     } else {
 	
@@ -525,6 +533,102 @@ void GUI::MenuWindow::btn_item_cb (bool separator)
 
     clist->select_row (new_row);
     res->set_submenus (submenus);
-
+    UndoOp *op = new MenuItemCreateOp (res, parent_index, index);
+    res->get_manager ()->get_undo_manager ().push (op);
+	
+    while (Gtk::Main::events_pending ())
+	Gtk::Main::iteration ();
     item_id->grab_focus ();
 }
+
+void GUI::MenuWindow::submenu_up (unsigned int index)
+{
+    g_return_if_fail (index > 0);
+
+    std::vector<Resources::Menu::Submenu>::iterator curr = submenus.begin () + index;
+    std::vector<Resources::Menu::Submenu>::iterator prev = curr - 1;
+    int offset = prev->items.size() + 1;
+    
+    std::iter_swap (curr, prev);
+
+    UndoOp *op = new SubmenuMoveOp (res, index, index - 1);
+    res->set_submenus (submenus);
+    res->get_manager ()->get_undo_manager ().push (op);
+    
+    unsigned int row = clist->selection ().begin ()->get_row_num ();
+    clist->select_row (row - offset);
+}
+
+void GUI::MenuWindow::submenu_down (unsigned int index)
+{
+    g_return_if_fail (index < (submenus.size() - 1));
+    
+    std::vector<Resources::Menu::Submenu>::iterator curr = submenus.begin() + index;
+    std::vector<Resources::Menu::Submenu>::iterator next = curr + 1;
+    int offset = next->items.size() + 1;
+
+    std::iter_swap (curr, next);
+
+    UndoOp *op = new SubmenuMoveOp (res, index, index + 1);
+    res->set_submenus (submenus);
+    res->get_manager ()->get_undo_manager ().push (op);
+    
+    unsigned int row = clist->selection ().begin ()->get_row_num ();
+    clist->select_row (row + offset);
+}
+
+void GUI::MenuWindow::submenu_remove (unsigned int index)
+{
+    submenus.erase (submenus.begin () + index);
+
+    UndoOp *op = new SubmenuRemoveOp (res, index);
+    res->set_submenus (submenus);
+    res->get_manager ()->get_undo_manager ().push (op);
+}
+	
+void GUI::MenuWindow::menuitem_up (unsigned int parent_index,
+				   unsigned int index)
+{
+    std::vector<Resources::Menu::MenuItem> &items = submenus[parent_index].items;
+    std::vector<Resources::Menu::MenuItem>::iterator curr = items.begin() + index;
+    std::vector<Resources::Menu::MenuItem>::iterator prev = curr - 1;
+    
+    std::iter_swap (curr, prev);
+
+    UndoOp *op = new MenuItemMoveOp (res, parent_index, index, index - 1);
+    res->set_submenus (submenus);
+    res->get_manager ()->get_undo_manager ().push (op);
+    
+    unsigned int row = clist->selection ().begin ()->get_row_num ();
+    clist->select_row (row - 1);
+}
+
+void GUI::MenuWindow::menuitem_down (unsigned int parent_index,
+				     unsigned int index)
+{
+    std::vector<Resources::Menu::MenuItem>& items = submenus[parent_index].items;
+    std::vector<Resources::Menu::MenuItem>::iterator curr = items.begin() + index;
+    std::vector<Resources::Menu::MenuItem>::iterator next = curr + 1;
+
+    g_return_if_fail (index < (items.size () - 1));
+    
+    std::iter_swap (curr, next);
+
+    UndoOp *op = new MenuItemMoveOp (res, parent_index, index, index + 1);
+    res->set_submenus (submenus);
+    res->get_manager ()->get_undo_manager ().push (op);
+    
+    unsigned int row = clist->selection ().begin ()->get_row_num ();
+    clist->select_row (row + 1);
+}
+
+void GUI::MenuWindow::menuitem_remove (unsigned int parent_index,
+				       unsigned int index)
+{
+    std::vector<Resources::Menu::MenuItem>& items = submenus[parent_index].items;
+    items.erase (items.begin () + index);
+    
+    UndoOp *op = new MenuItemRemoveOp (res, parent_index, index);
+    res->set_submenus (submenus);
+    res->get_manager ()->get_undo_manager ().push (op);
+}
