@@ -1,4 +1,4 @@
-//$Id: menu-win.h,v 1.10 2002/01/04 17:34:28 cactus Exp $ -*- c++ -*-
+//$Id: menu-win.h,v 1.11 2002/10/29 18:19:41 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -92,6 +92,14 @@ namespace Guikachu
 	    
 	    void clist_sel_row (gint row, gint column,
 				GdkEvent *event);
+
+	    void submenu_up     (unsigned int index);
+	    void submenu_down   (unsigned int index);
+	    void submenu_remove (unsigned int index);
+	    
+	    void menuitem_up     (unsigned int parent_index, unsigned int index);
+	    void menuitem_down   (unsigned int parent_index, unsigned int index);
+	    void menuitem_remove (unsigned int parent_index, unsigned int index);
 	};
     };
 };
