@@ -1,4 +1,4 @@
-//$Id: property.cc,v 1.12 2002/06/02 13:53:36 cactus Exp $ -*- c++ -*-
+//$Id: property.cc,v 1.15 2003/01/29 20:29:58 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -41,33 +41,71 @@ void ID::set_val (const std::string &value_)
 namespace Guikachu
 {
 
+
+// The following is needed to make sure the object really contains the
+// required specializations
+namespace
+{
+    static void foo ()
+    {
+	VSignal s;
+	
+	Property<std::string>               x1 (s);
+	Property<std::vector<std::string> > x2 (s);
+    }
+    
+} // anonymous namespace
+
+
+    
+std::string make_7bit_string (const std::string &str)
+{
+    std::string ret;
+
+    for (std::string::const_iterator i = str.begin ();
+	 i != str.end (); ++i)
+    {
+	// Convert non-ASCII characters to _ placeholder
+	if ((signed char)*i < 0)
+	    ret += '_';
+	else
+	    ret += *i;
+    }
+
+    return ret;
+}
+    
 template<>
 void Property<std::string>::set_val (const std::string &value_)
 {
-    if (value_ == value)
+    std::string ascii_value = make_7bit_string (value_);
+
+    if (ascii_value == value)
 	return;
-    
-    std::string ascii_value = value_;
-    
-    for (std::string::iterator i = ascii_value.begin ();
-	 i != ascii_value.end (); i++)
-    {
-	// Convert non-ASCII characters to _ placeholder
-	if (*i < 0)
-	    *i = '_';
-    }
-    
+
     value = ascii_value;
     changed ();
 }
 
 template<>
-std::ostream & operator<< (std::ostream &ostr, const Property<std::string> &prop)
+void Property<std::vector<std::string> >::set_val (const std::vector<std::string> &value_)
+{
+    std::vector<std::string> ascii_values (value_.size ());
+    std::transform (value_.begin (), value_.end (),
+		    ascii_values.begin (), make_7bit_string);
+
+    if (ascii_values == value)
+	return;
+
+    value = ascii_values;
+    changed ();
+}
+
+std::string escape_backslashes (const std::string &src)
 {
     std::string escaped_string;
-    const std::string &src = prop.value;
 
-    for (std::string::const_iterator i = src.begin (); i != src.end (); i++)
+    for (std::string::const_iterator i = src.begin (); i != src.end (); ++i)
     {
 	if (*i == '\\')
 	{
@@ -110,8 +148,13 @@ std::ostream & operator<< (std::ostream &ostr, const Property<std::string> &prop
 	escaped_string += *i;
     }
 
-    ostr << escaped_string;
-    
+    return escaped_string;
+}
+
+template<>
+std::ostream & operator<< (std::ostream &ostr, const Property<std::string> &prop)
+{
+    ostr << escape_backslashes (prop.value);
     return ostr;
 }
     
