@@ -1,4 +1,4 @@
-//$Id: resource-manager.cc,v 1.42 2002/11/10 20:06:06 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager.cc,v 1.44 2003/01/25 00:33:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -117,12 +117,7 @@ std::string ResourceManager::create_id (const std::string &prefix)
 bool ResourceManager::register_id (const std::string &id)
 {
     if (id_set.find (id) != id_set.end ())
-    {
-	char *error_msg = g_strdup_printf (_("Non-unique identifier `%s'"), id.c_str ());
-	GUI::show_error (error_msg);
-	g_free (error_msg);
 	return false;
-    }
 
     id_set.insert (id);
     return true;
@@ -147,7 +142,8 @@ std::string ResourceManager::validate_id (std::string id)
 }
 
 Resource* ResourceManager::create_resource (Resources::Type type,
-					    std::string     id)
+					    std::string     id,
+					    bool            try_alternate_names)
 {
     g_return_val_if_fail (type != Resources::RESOURCE_NONE, 0);
     
@@ -157,38 +153,38 @@ Resource* ResourceManager::create_resource (Resources::Type type,
 	id = create_id (Resources::prefix_from_type (type));
     
     if (!register_id (id))
-	return 0;
-
-    std::string real_id = id;
-    for (std::string::iterator i = real_id.begin ();
-	 i != real_id.end (); i++)
     {
-	if (*i == ' ')
-	    *i = '_';
+	if (try_alternate_names) // if FOO is taken, try FOO_1
+	{
+	    id = create_id (id + "_");
+	    register_id (id);
+	} else {
+	    return 0;
+	}
     }
-    
+
     Resource *res;
     Resources::Form *form = 0;
 
     switch (type)
     {
     case Resources::RESOURCE_DIALOG:
-	res = new Resources::Dialog (this, real_id);
+	res = new Resources::Dialog (this, id);
 	break;
     case Resources::RESOURCE_STRING:
-	res = new Resources::String (this, real_id);
+	res = new Resources::String (this, id);
 	break;
     case Resources::RESOURCE_STRINGLIST:
-	res = new Resources::StringList (this, real_id);
+	res = new Resources::StringList (this, id);
 	break;
     case Resources::RESOURCE_BLOB:
-	res = new Resources::Blob (this, real_id);
+	res = new Resources::Blob (this, id);
 	break;
     case Resources::RESOURCE_MENU:
-	res = new Resources::Menu (this, real_id);
+	res = new Resources::Menu (this, id);
 	break;
     case Resources::RESOURCE_FORM:
-	form = new Resources::Form (this, real_id);
+	form = new Resources::Form (this, id);
 	form->widget_changed.connect (SigC::slot (this, &ResourceManager::set_dirty));
 	res = form;
 	break;
@@ -196,7 +192,7 @@ Resource* ResourceManager::create_resource (Resources::Type type,
 	g_assert_not_reached ();
     }
     
-    resource_map.insert (std::make_pair (real_id, res));
+    resource_map.insert (std::make_pair (id, res));
 
     res->changed.connect (SigC::slot (this, &ResourceManager::set_dirty));
 
