@@ -1,4 +1,4 @@
-//$Id: resource-ref.h,v 1.6 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: resource-ref.h,v 1.7 2002/06/02 13:53:36 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -30,11 +30,13 @@ namespace Guikachu
 	class ResourceRef: public Property<std::string>,
 			   public SigC::Object
 	{
+	    ResourceManager  *manager;
 	    Resource         *current_resource;
 	    SigC::Connection  current_resource_changed;
 	    
 	public:
 	    ResourceRef (notify_signal_t   &notify_signal,
+			 ResourceManager   *manager,
 			 const std::string &value = "");
 	    
 	    virtual void set_val (const std::string &value);
