@@ -1,4 +1,4 @@
-//$Id: resource-tree.cc,v 1.3 2002/08/22 15:17:14 cactus Exp $ -*- c++ -*-
+//$Id: resource-tree.cc,v 1.4 2003/01/25 16:11:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -68,6 +68,20 @@ void GUI::ResourceTree::set_manager (ResourceManager *manager_)
     manager->resource_removed.connect (slot (this, &ResourceTree::resource_removed_cb));
 }
 
+Resource * GUI::ResourceTree::get_selected () const
+{
+    const Gtk::Tree::SelectionList &selection_list = selection ();
+
+    if (!selection_list.size ())
+	return 0;
+
+    Gtk::TreeItem *selected_item = *(selection_list.begin ());
+    if (GUI::TreeItem *item = dynamic_cast<GUI::TreeItem*> (selected_item))
+	return item->get_resource ();
+
+    return 0;
+}
+
 void GUI::ResourceTree::resource_created_cb (Resource *resource)
 {
     TreeItem *item = new GUI::TreeItem (resource);
