@@ -1,4 +1,4 @@
-//$Id: resource.cc,v 1.11 2002/06/08 14:28:53 cactus Exp $ -*- c++ -*-
+//$Id: resource.cc,v 1.12 2003/01/25 00:33:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -20,9 +20,9 @@
 
 using namespace Guikachu;
 
-Resource::Resource (ResourceManager   *owner_,
+Resource::Resource (ResourceManager   *manager_,
 		    const std::string &id_):
-    owner (owner_),
-    id (changed, owner, id_)
+    manager (manager_),
+    id (changed, manager, id_)
 {
 }
