@@ -1,4 +1,4 @@
-//$Id: resource.h,v 1.28 2002/08/01 18:06:01 cactus Exp $ -*- c++ -*-
+//$Id: resource.h,v 1.29 2003/01/25 00:33:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -50,15 +50,15 @@ namespace Guikachu
     class Resource: public SigC::Object
     {
     protected:
-	Resource (ResourceManager   *owner,
+	Resource (ResourceManager   *manager,
 		  const std::string &id);
 
-	ResourceManager *owner;
+	ResourceManager *manager;
 	
     public:
 	virtual ~Resource () {};
 
-	ResourceManager * get_manager () { return owner; };
+	ResourceManager * get_manager () { return manager; };
 	
 	// Resource managment functions
 	virtual Resources::Type get_type () const = 0;
