@@ -1,4 +1,4 @@
-//$Id: storage-node.cc,v 1.21 2002/08/13 23:55:50 cactus Exp $ -*- c++ -*-
+//$Id: storage-node.cc,v 1.22 2003/01/25 00:33:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -124,7 +124,7 @@ namespace
 	
 	for (std::string::const_iterator i = raw_str.begin (); i != raw_str.end (); ++i)
 	{
-	    if (*i < 0)
+	    if ((signed char)*i < 0)
 	    {
 		converted = true;
 		
