@@ -1,4 +1,4 @@
-//$Id: storage.cc,v 1.7 2002/08/15 23:09:59 cactus Exp $ -*- c++ -*-
+//$Id: storage.cc,v 1.9 2003/01/25 16:11:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -24,17 +24,36 @@
 
 using namespace Guikachu;
 
-Storage::Storage ():
+Storage::Storage () :
     doc (xmlNewDoc ((xmlChar*)"1.0"))
 {
 }
 
+Storage::Storage (xmlDocPtr doc_) :
+    doc (doc_)
+{
+}
+
 Storage::~Storage ()
 {
     if (doc)
 	xmlFreeDoc (doc);
 }
 
+Storage::Storage (const Storage &other) :
+    doc (xmlCopyDoc (other.doc, 1))
+{
+}
+
+Storage & Storage::operator= (const Storage &other)
+{
+    if (doc)
+	xmlFreeDoc (doc);
+
+    doc = xmlCopyDoc (other.doc, 1);
+    return *this;
+}
+
 GnomeVFSResult Storage::load (const std::string &filename)
 {
     if (doc)
@@ -122,34 +141,35 @@ GnomeVFSResult Storage::save_uri (const std::string &uri) const
     GnomeVFSHandle *vfs_handle = 0;
     GnomeVFSResult  res = gnome_vfs_create (&vfs_handle, uri.c_str (),
 					    GNOME_VFS_OPEN_WRITE, 0, 0644);
-
     if (res != GNOME_VFS_OK)
 	goto error;
 
-    xmlDocDumpMemory (doc, &buffer, &buffer_size);
+    save_buffer (buffer, buffer_size);
 
     GnomeVFSFileSize bytes_written;
     res = gnome_vfs_write (vfs_handle, buffer, buffer_size, &bytes_written);
+
+    xmlFree (buffer);
+    
     if (res != GNOME_VFS_OK)
 	goto error;
     
     res = gnome_vfs_close (vfs_handle);
-    vfs_handle = 0;
-    if (res != GNOME_VFS_OK)
-	goto error;
 
-    return GNOME_VFS_OK;
+    return res;
 
  error:
     if (vfs_handle)
 	gnome_vfs_close (vfs_handle);
 
-    if (buffer)
-	xmlFree (buffer);
-    
     return res;
 }
 
+void Storage::save_buffer (xmlChar *&buffer, int &buffer_size) const
+{
+    xmlDocDumpMemory (doc, &buffer, &buffer_size);    
+}
+
 StorageNode Storage::get_root ()
 {
     g_assert (doc != 0);
