@@ -1,4 +1,4 @@
-//$Id: target.cc,v 1.9 2002/06/19 16:08:06 cactus Exp $ -*- c++ -*-
+//$Id: target.cc,v 1.10 2002/08/12 22:59:16 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -36,23 +36,23 @@ namespace
 {
     struct StockTargetData
     {
-	std::string description;
+	Target::stock_desc_t description;
 	int screen_width;
 	int screen_height;
 
-	StockTargetData (const std::string &description_,
-			 int                screen_width_,
-			 int                screen_height_):
+	StockTargetData (const Target::stock_desc_t &description_,
+			 int                         screen_width_,
+			 int                         screen_height_):
 	    description (description_),
 	    screen_width (screen_width_),
 	    screen_height (screen_height_)
 	    {}
     };
 
-    typedef std::map<std::string, StockTargetData> StockTargetCache;
+    typedef std::map<Target::stock_id_t, StockTargetData> StockTargetCache;
     static StockTargetCache stock_target_cache;
-    static const StockTargetData& get_stock_data (const std::string &stock_id);
-    static StockTargetData load_stock_data (const std::string &stock_id);
+    static const StockTargetData& get_stock_data (const Target::stock_id_t &stock_id);
+    static StockTargetData load_stock_data (const Target::stock_id_t &stock_id);
 }
 
 
@@ -62,7 +62,7 @@ Target::Target ():
 {
     load_stock (get_default_stock_id ());
 
-    changed.connect (SigC::slot (this, &Target::changed_cb));
+    changed.connect (SigC::slot (*this, &Target::changed_cb));
 }
 
 void Target::changed_cb ()
@@ -76,7 +76,7 @@ std::string Target::get_default_stock_id ()
     return "palm";
 }
 
-void Target::load_stock (const std::string &stock_id_)
+void Target::load_stock (const Target::stock_id_t &stock_id_)
 {
     g_return_if_fail (stock_id_ != "");
     
@@ -92,21 +92,21 @@ void Target::load_stock (const std::string &stock_id_)
     changed ();
 }
 
-std::string Target::get_stock_id () const
+Target::stock_id_t Target::get_stock_id () const
 {
     return stock_id;
 }
 
-std::map<std::string, std::string> Target::stock_targets ()
+Target::stock_list_t Target::stock_targets ()
 {
-    std::map<std::string, std::string> ret_val;
+    Target::stock_list_t ret_val;
 
     DIR    *target_def_dir = opendir (GUIKACHU_TARGETDIR);
     g_return_val_if_fail (target_def_dir != 0, ret_val);
 
     dirent       *target_def_dirent;
     std::string   filename;
-    std::string   id;
+    stock_id_t    id;
 
     while ((target_def_dirent = readdir (target_def_dir)) != 0)
     {
@@ -117,7 +117,7 @@ std::map<std::string, std::string> Target::stock_targets ()
 	if (i == (filename.length () - strlen (".guikachu-target")))
 	{
 	    // ... then chop it off
-	    id = std::string (filename, 0, i);
+	    id = stock_id_t (filename, 0, i);
 
 	    // Load the target definition into cache, and return its
 	    // ID and description
@@ -131,7 +131,7 @@ std::map<std::string, std::string> Target::stock_targets ()
 }
 
 namespace {
-const StockTargetData& get_stock_data (const std::string &stock_id)
+const StockTargetData& get_stock_data (const Target::stock_id_t &stock_id)
 {
     // Look up cache first
     StockTargetCache::const_iterator cache_hit = stock_target_cache.find (stock_id);
@@ -149,9 +149,9 @@ const StockTargetData& get_stock_data (const std::string &stock_id)
     return cache_hit->second;
 }
 
-StockTargetData load_stock_data (const std::string &stock_id)
+StockTargetData load_stock_data (const Target::stock_id_t &stock_id)
 {
-    std::string description = stock_id;
+    Target::stock_desc_t description = Target::stock_desc_t (stock_id);
     int screen_width = 160;
     int screen_height = 160;
     
@@ -161,6 +161,7 @@ StockTargetData load_stock_data (const std::string &stock_id)
     Storage target_def;
     target_def.load (filename);
     StorageNode root_node = target_def.get_root ();
+
     if (root_node.name () != "guikachu-target")
     {
 	g_warning ("`%s' is not a valid Guikachu target definition",
@@ -171,8 +172,7 @@ StockTargetData load_stock_data (const std::string &stock_id)
     // Load translated entries first
     description = root_node.get_translated_child ("description").get_content_raw ();
     
-    for (StorageNode curr_node = root_node.children ();
-	 curr_node; curr_node++)
+    for (StorageNode curr_node = root_node.children (); curr_node; ++curr_node)
     {
 	if (curr_node.name () == "description")
 	    // Already loaded -- mentioned here only to surpass waning
