@@ -1,4 +1,4 @@
-//$Id: target.h,v 1.6 2002/06/22 13:03:40 cactus Exp $ -*- c++ -*-
+//$Id: target.h,v 1.7 2002/08/12 22:59:16 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -29,16 +29,22 @@ namespace Guikachu
 {
     class Target: public SigC::Object
     {
-	std::string stock_id;
+    public:
+	typedef std::string stock_id_t;
+	typedef std::string stock_desc_t;
+	typedef std::map<stock_id_t, stock_desc_t> stock_list_t;
+
+    private:
+	stock_id_t stock_id;
 
     public:
 	Target ();
 	
-	void        load_stock   (const std::string &stock_id);
-	std::string get_stock_id () const;
+	void       load_stock   (const stock_id_t &stock_id);
+	stock_id_t get_stock_id () const;
 
-	static std::map<std::string, std::string> stock_targets ();
-	static std::string get_default_stock_id ();
+	static stock_list_t stock_targets ();
+	static stock_id_t get_default_stock_id ();
 	
 	VSignal changed;
 	
