@@ -1,4 +1,4 @@
-//$Id: treeitem.h,v 1.5 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: treeitem.h,v 1.6 2003/01/25 16:11:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -42,14 +42,18 @@ namespace Guikachu
 	    
 	public:
 	    TreeItem (Resource *res_);
+
+	    Resource * get_resource () const { return res; };
 	    
 	private:
 	    int button_press_cb (GdkEventButton *e);
 	    int key_press_cb (GdkEventKey *e);
 	    void resource_changed_cb ();
 
-	    void menu_remove_cb ();
 	    void menu_edit_cb ();
+	    void menu_cut_cb ();
+	    void menu_copy_cb ();
+	    void menu_remove_cb ();
 	};
     }
 }
