@@ -1,4 +1,4 @@
-//$Id: undo.cc,v 1.1 2002/08/02 16:07:58 cactus Exp $ -*- c++ -*-
+//$Id: undo.cc,v 1.4 2002/10/30 23:27:27 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -18,6 +18,8 @@
 
 #include "undo.h"
 
+#include "preferences.h"
+
 using namespace Guikachu;
 
 UndoManager::UndoStack::~UndoStack ()
@@ -34,16 +36,26 @@ void UndoManager::UndoStack::clear ()
     impl_stack.clear ();
 }
 
-void UndoManager::UndoStack::truncate (size_type max_size)
+UndoManager::UndoStack::size_type UndoManager::UndoStack::size () const
 {
-    if (impl_stack.size () < max_size)
-	return;
+    return impl_stack.size ();
+}
 
+// returns number of removed items
+UndoManager::UndoStack::size_type UndoManager::UndoStack::truncate (size_type max_size)
+{
+    if (size () <= max_size)
+	return 0;
+
+    size_type num_truncated = size () - max_size;
+    
     impl_stack_t::iterator del_begin = impl_stack.begin ();
-    impl_stack_t::iterator del_end = del_begin + (impl_stack.size () - max_size);
+    impl_stack_t::iterator del_end = del_begin + num_truncated;
     for (impl_stack_t::iterator i = del_begin; i != del_end; ++i)
 	delete *i;
     impl_stack.erase (del_begin, del_end);
+
+    return num_truncated;
 }
 
 UndoManager::UndoStack::value_t UndoManager::UndoStack::top () const
@@ -78,6 +90,11 @@ std::list<std::string> UndoManager::UndoStack::get_labels () const
 }
 
 
+UndoManager::UndoManager () :
+    origin (0),
+    origin_valid (true)
+{
+}
 
 void UndoManager::push (UndoOp *op)
 {
@@ -97,6 +114,9 @@ void UndoManager::undo ()
 
     push_redo (top_op);
     changed.emit ();
+
+    if (origin_valid && origin == undo_stack.size ())
+	origin_reached.emit ();
 }
 
 
@@ -109,6 +129,9 @@ void UndoManager::redo ()
     
     push_undo (top_op);
     changed.emit ();
+    
+    if (origin_valid && origin == undo_stack.size ())
+	origin_reached.emit ();
 }
 
 void UndoManager::push_undo (UndoOp *op)
@@ -133,21 +156,25 @@ void UndoManager::push_undo (UndoOp *op)
 void UndoManager::push_redo (UndoOp *op)
 {
     redo_stack.push (op);
-    truncate_redo_stack ();
 }
 
 void UndoManager::truncate_undo_stack ()
 {
-    unsigned int undo_max_size = 10; // FIXME: get this from GConf
+    unsigned int undo_max_size = Preferences::Interface::get_undo_size ();
 
-    undo_stack.truncate (undo_max_size);
+    UndoStack::size_type num_truncated = undo_stack.truncate (undo_max_size);
+
+    if (origin_valid)
+	if (num_truncated > origin)
+	    origin_valid = false;
+	else
+	    origin -= num_truncated;
 }
 
-void UndoManager::truncate_redo_stack ()
+void UndoManager::set_origin ()
 {
-    unsigned int redo_max_size = 10; // FIXME: get this from GConf
-
-    redo_stack.truncate (redo_max_size);
+    origin = undo_stack.size ();
+    origin_valid = true;
 }
 
 std::list<std::string> UndoManager::get_undo_labels () const
