@@ -1,4 +1,4 @@
-//$Id: auto-toggle.cc,v 1.4 2002/01/01 21:23:42 cactus Exp $ -*- c++ -*-
+//$Id: auto-toggle.cc,v 1.5 2002/10/26 15:55:40 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -20,11 +20,13 @@
 
 using namespace Guikachu::GUI::PropertyEditors;
 
-AutoToggle::AutoToggle (Gtk::Widget    &widget_,
-			Property<bool> &property_):
+AutoToggle::AutoToggle (Gtk::Widget  &widget_,
+			property_t   &property_,
+			op_factory_t *op_factory_) :
     PropertyEditor (this),
     widget (widget_),
     property (property_),
+    op_factory (op_factory_),
     update_block (false)
 {
     using namespace SigC;
@@ -53,6 +55,8 @@ void AutoToggle::update ()
 
 void AutoToggle::clicked_cb ()
 {
-    if (!update_block)
-	property = togglebutton.get_active ();
+    if (update_block)
+	return;
+
+    op_factory->push_change (togglebutton.get_active ());
 }
