@@ -1,4 +1,4 @@
-//$Id: auto-toggle.h,v 1.4 2002/01/01 21:23:42 cactus Exp $ -*- c++ -*-
+//$Id: auto-toggle.h,v 1.5 2002/10/26 15:55:41 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,7 +21,9 @@
 
 #include <gtk--/checkbutton.h>
 #include <gtk--/box.h>
+
 #include "property.h"
+#include "property-ops.h"
 #include "property-editor.h"
 
 namespace Guikachu
@@ -35,12 +37,17 @@ namespace Guikachu
 	    {
 		Gtk::CheckButton  togglebutton;
 		Gtk::Widget      &widget;
-		
-		Property<bool>   &property;
+
+		typedef Property<bool>            property_t;
+		typedef PropChangeOpFactory<bool> op_factory_t;
+
+		property_t                  &property;
+		std::auto_ptr<op_factory_t>  op_factory;
 		
 	    public:
-		AutoToggle (Gtk::Widget    &widget,
-			    Property<bool> &property);
+		AutoToggle (Gtk::Widget  &widget,
+			    property_t   &property,
+			    op_factory_t *op_factory);
 		
 		//void install_underline;
 	    private:
