@@ -1,4 +1,4 @@
-//$Id: num-entry.cc,v 1.5 2002/01/01 21:23:42 cactus Exp $ -*- c++ -*-
+//$Id: num-entry.cc,v 1.6 2002/10/26 15:55:41 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,9 +23,11 @@
 using namespace Guikachu::GUI::PropertyEditors;
 
 NumEntry::NumEntry (int min, int max,
-		    Property<int> &property_):
+		    property_t   &property_,
+		    op_factory_t *op_factory_):
     PropertyEditor (this),
     property (property_),
+    op_factory (op_factory_),
     update_block (false)
 {
     using namespace SigC;
@@ -62,6 +64,8 @@ void NumEntry::update ()
 
 void NumEntry::changed_cb ()
 {
-    if (!update_block)
-	property = get_value_as_int ();
+    if (update_block)
+	return;
+
+    op_factory->push_change (get_value_as_int ());
 }
