@@ -1,4 +1,4 @@
-//$Id: pos-entry.h,v 1.7 2002/06/02 13:53:43 cactus Exp $ -*- c++ -*-
+//$Id: pos-entry.h,v 1.8 2002/10/26 15:55:41 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -34,7 +34,8 @@ namespace Guikachu
 	    {
 	    public:
 		XPosEntry (ResourceManager *manager,
-			   Property<int>   &property);
+			   property_t      &property,
+			   op_factory_t    *op_factory);
 	    private:
 		Target *target;
 		
@@ -45,7 +46,8 @@ namespace Guikachu
 	    {
 	    public:
 		YPosEntry (ResourceManager *manager,
-			   Property<int>   &property);
+			   property_t      &property,
+			   op_factory_t    *op_factory);
 	    private:
 		Target *target;
 		
