@@ -1,4 +1,4 @@
-//$Id: string-list.cc,v 1.13 2002/07/07 15:00:33 cactus Exp $ -*- c++ -*-
+//$Id: string-list.cc,v 1.14 2002/11/10 16:47:04 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -27,9 +27,11 @@
 
 using namespace Guikachu::GUI::PropertyEditors;
 
-StringList::StringList (Property<value_t> &property_):
+StringList::StringList (property_t   &property_,
+			op_factory_t *op_factory_) :
     Gtk::HBox (false, 5),
     property (property_),
+    op_factory (op_factory_),
     buttons (new Gtk::VButtonBox),
     update_block (false),
     saved_pos (-1)
@@ -195,13 +197,11 @@ unsigned int StringList::get_selected_row ()
 void StringList::button_remove_cb ()
 {
     unsigned int index = get_selected_row ();
-    value_t val = property;
-    val.erase (val.begin () + index);
 
     saved_pos = MIN (index, property ().size () - 2);
 
-    property = val;
-
+    op_factory->push_remove (index);
+    
     item_removed.emit (index);
 }
 
@@ -210,14 +210,9 @@ void StringList::button_up_cb ()
     unsigned int index = get_selected_row ();
     g_return_if_fail (index != 0);
 
-    value_t val = property;
-    value_t::iterator curr = val.begin () + index;
-    value_t::iterator prev = curr - 1;
-    iter_swap (curr, prev);
-
     saved_pos = index - 1;
-    
-    property = val;
+
+    op_factory->push_move (index, index - 1);
     
     up.emit (index);
     update ();
@@ -228,15 +223,10 @@ void StringList::button_down_cb ()
     unsigned int index = get_selected_row ();
     g_return_if_fail (index < list_widget.items ().size () - 1);
 
-    value_t val = property;
-    value_t::iterator curr = val.begin () + index;
-    value_t::iterator next = curr + 1;
-    iter_swap (curr, next);
-
     saved_pos = index + 1;
 
-    property = val;
-
+    op_factory->push_move (index, index + 1);
+    
     down.emit (index);
     update ();
 }
@@ -251,18 +241,11 @@ void StringList::button_add_cb ()
     std::string item_text = entry.get_text ();
     if (item_text == "")
 	return;
-    
-    value_t curr_val = property;
-    value_t::iterator pos = curr_val.begin () + index + 1;
-    if (index == curr_val.size ())
-	curr_val.push_back (item_text);
-    else
-	curr_val.insert (pos, item_text);
 
     saved_pos = index + 1;
-    
-    property = curr_val;
 
+    op_factory->push_add (index + 1, item_text);
+    
     item_added.emit (index + 1);
 }
 
@@ -284,8 +267,5 @@ void StringList::entry_activate_cb ()
 
     saved_pos = index;
 
-    value_t val = property;
-
-    val[index] = new_text;
-    property = val;
+    op_factory->push_change (index, new_text);
 }
